package com.ruoyi.SafetyDeclaration.service;

import java.util.List;
import com.ruoyi.SafetyDeclaration.domain.SafetyDeclarationTable;

/**
 * 水电校园安全不良事件
Service接口
 * 
 * @author ruoyi
 * @date 2024-08-04
 */
public interface ISafetyDeclarationTableService 
{
    /**
     * 查询水电校园安全不良事件

     * 
     * @param id 水电校园安全不良事件
主键
     * @return 水电校园安全不良事件

     */
    public SafetyDeclarationTable selectSafetyDeclarationTableById(Long id);

    /**
     * 查询水电校园安全不良事件
列表
     * 
     * @param safetyDeclarationTable 水电校园安全不良事件

     * @return 水电校园安全不良事件
集合
     */
    public List<SafetyDeclarationTable> selectSafetyDeclarationTableList(SafetyDeclarationTable safetyDeclarationTable);

    /**
     * 新增水电校园安全不良事件

     * 
     * @param safetyDeclarationTable 水电校园安全不良事件

     * @return 结果
     */
    public int insertSafetyDeclarationTable(SafetyDeclarationTable safetyDeclarationTable);

    /**
     * 修改水电校园安全不良事件

     * 
     * @param safetyDeclarationTable 水电校园安全不良事件

     * @return 结果
     */
    public int updateSafetyDeclarationTable(SafetyDeclarationTable safetyDeclarationTable);

    /**
     * 批量删除水电校园安全不良事件

     * 
     * @param ids 需要删除的水电校园安全不良事件
主键集合
     * @return 结果
     */
    public int deleteSafetyDeclarationTableByIds(Long[] ids);

    /**
     * 删除水电校园安全不良事件
信息
     * 
     * @param id 水电校园安全不良事件
主键
     * @return 结果
     */
    public int deleteSafetyDeclarationTableById(Long id);
}
